@@ -23,6 +23,7 @@ class ProxyServer:
         self.target = clientPorxyTarget
         self.proxyStopped = False
         self.proxyRunningEvent = Event()
+        self.remoteTarget = None
 
     def _run(self):
         s = scheduler.Scheduler(200)
@@ -35,7 +36,9 @@ class ProxyServer:
                 logger.info(f"Server is running on bound port {self.port}")
                 with server.accept() as rpcClientSession:
                     logger.info("Client part of proxy connected.")
+                    self.remoteTarget = rpcClientSession.get_remote_target_proxy()
                     rpcClientSession.set_target(self.target)
+                    rpcClientSession.wait_remote_target_set()
                     self.proxyRunningEvent.set()
                     logger.info("Clinet proxy target set. Waiting till stop_proxy_server is called")
                     while not self.proxyStopped:
@@ -59,7 +62,12 @@ class ProxyServer:
         logger.info("stop_proxy_server has been called")
         self.proxyStopped = True
         self.server.stop()
-
+        
+    def call_client_function(self, functionName, kwargs):
+        if self.remoteTarget:
+            return self.remoteTarget.call_on_client_stub(functionName, kwargs)
+        else:
+            raise RuntimeError("No remote target set. Required for call_client_function")
 
 
 def init_proxy_server(proxyConfigPath, clientPorxyTarget)->ProxyServer:
